#if !defined(EHCMQ_INCLUDED)             /* File not yet included?      */
  #define EHCMQ_INCLUDED                 /* Show file now included      */
/******************************************************************************/
/*                                                                            */
/*                                EHCMQ.H                                     */
/*                                                                            */
/*                      LAN Distributed Platform - LANDP                      */
/*                                                                            */
/*                 5639-I90 (C) Copyright IBM Corp 2000                       */
/*         All Rights Reserved - Licensed Materials - Property of IBM         */
/*                                                                            */
/* This sample program header file has been provided to aid the development   */
/* of LANDP client applications and their use of the MQSeries Link server.    */
/*                                                                            */
/******************************************************************************/

#define EHCMQ_SERVER   "EHCMQ## "    /* 8 characters left justified  */


/* LANDP MQseries Link server Functions
   ------------------------------------
 */
#define EHC_BeginTran   0x4254       /* BT  Begin Transaction        */
#define EHC_CheckPoint  0x4350       /* CP  Check Point Transaction  */
#define EHC_CloseSes    0x4353       /* CS  Close Session            */
#define EHC_CloseQ      0x4351       /* CQ  Close Queue              */
#define EHC_EndTran     0x4554       /* ET  End Transaction          */
#define EHC_GetQ        0x4751       /* GQ  Get Queue                */
#define EHC_PutQ        0x5051       /* PQ  Put Queue                */
#define EHC_Put1        0x5031       /* P1  Put 1 message onto queue */
#define EHC_RollBack    0x5242       /* RB  Roll Back Transaction    */


/* LANDP MQseries Link server Return Codes
   ---------------------------------------
 */
#define OK 0x0000                 /* Successful return code          */
#define BH 0x4248 /* NEW */       /* Bad Queue Handle                */ /* not in V5 doc */
#define CB 0x4342 /* NEW */       /* MQ server Connection is broken  */ /* not in V5 doc */
#define CQ 0x4351                 /* Connect Queue, MQCONN error     */
#define DQ 0x4451                 /* Disconnect Queue, MQDISC error  */
#define ER 0x4552                 /* General error, default error    */
#define GE 0x4745                 /* GQ, MQGET error                 */
#define GW 0x4757 /* NEW */       /* GQ warning, data problem        */ /* not in V5 doc */ 
#define IT 0x4954                 /* GQ Browse, In Transaction       */
#define MX 0x4D58                 /* Resource limit has been reached */
#define NM 0x4E4D                 /* GQ, No message                  */
#define OP 0x4F50                 /* GQ, PQ or P1 bad options        */
#define OQ 0x4F51                 /* GQ or PQ, MQOPEN error          */
#define P1 0x5031                 /* Unrecognised Function           */
#define P2 0x5032                 /* Length error, incorrect length  */
#define P4 0x5034                 /* Parmlist error                  */
#define PE 0x5045                 /* PQ, MQPUT error                 */
#define SB 0x5342                 /* Session Busy error              */
#define SQ 0x5351                 /* Shut Queue, MQCLOSE error       */
#define TC 0x5443 /* NEW */       /* Thread communication error      */ /* not in V5 doc */
#define TE 0x5445                 /* Transaction error               */

/* LANDP GQ Message Options
   ------------------------
 */
#define EHCGQ_NONE                    0x0000
#define EHCGQ_CONVERT                 0x0001
#define EHCGQ_FAIL_IF_QUIESCING       0x0002
#define EHCGQ_WAIT                    0x0004
#define EHCGQ_ACCEPT_TRUNCATED_MSG    0x0008
#define EHCGQ_BROWSE_FIRST            0x0100
#define EHCGQ_BROWSE_MSG_UNDER_CURSOR 0x0200
#define EHCGQ_BROWSE_NEXT             0x0300


/* LANDP PQ Message Options
   ------------------------
 */
#define EHCPQ_NONE                    0x0000
#define EHCPQ_NEW_MSG_ID              0x0001
#define EHCPQ_NEW_CORREL_ID           0x0002
#define EHCPQ_FAIL_IF_QUIESCING       0x0004


/* LANDP Message Type Definitions
   ------------------------------
 */
#define EHCMT_DATAGRAM                0x4447    /* DG */
#define EHCMT_REQUEST                 0x5251    /* RQ */
#define EHCMT_REPLY                   0x5250    /* RP */
#define EHCMT_REPORT                  0x5254    /* RT */


/* LANDP MQseries Link server Limits
   ---------------------------------
*/
#define EHCMQMAX_SESSIONS           64
#define EHCMQMAX_MESSAGE         57000
#define EHCMQMIN_MESSAGE           100                 /* change from V5 doc */
#define EHCMQMAX_MQMNAMELEN         48
#define EHCMQMAX_LOGPATHLEN        128
#define EHCMQMAX_QUEUEHANDLE    0xFFFF    /* New, not documented in V5 books */


/* LANDP MQseries Link server Defaults
   -----------------------------------
*/
#define EHCMQDFLT_SESSIONS          32
#define EHCMQDFLT_STARTUP_CONNS      0
#define EHCMQDFLT_LOGDIR             "EHCMQLOG"
#define EHCMQDFLT_MAX_MSG_SIZE    1024                 /* change from V5 doc */


/* LANDP MQseries Link server time settings 
   ----------------------------------------
   Intended for PARMLIST fields GQ_REQUEST_PARM.wait and PQ_REQUEST_PARM.msgExp
*/
#define EHCMQDFLT_TIMEOUT            0        /* EHCMQ## will use ehctimeout */
#define EHCMQ_NO_TIMEOUT            -1        /* never expire                */


/* LANDP MQseries Link server Parmlist Field Lengths
   -------------------------------------------------
*/
#define EHCMQLEN_QName              24
#define EHCMQLEN_MsgId              24
#define EHCMQLEN_CorrelId           24
#define EHCMQLEN_UserId             12


/*****************************************************************************/
#pragma pack (1)


/*****************************************************************************/
/* CQ  Request PARMLIST type                                                 */
/*****************************************************************************/

typedef unsigned short QHANDLE;


/*****************************************************************************/
/* BT, CP, CS, CQ, ET & RB Reply PARMLIST type                               */
/*****************************************************************************/

typedef long MQREASON;

/*****************************************************************************/
/* Other types used in the following PARMLIST definitions                    */
/*****************************************************************************/

typedef unsigned short MSG_OPTION;
typedef unsigned short MSG_TYPE;


/*****************************************************************************/
/* GQ Request PARMLIST stucture                                              */
/*****************************************************************************/

typedef struct {
  QHANDLE        Qhandle;                        /* Queue Handle       */
  char           Qname[EHCMQLEN_QName];          /* Queue Name         */
  char           msgId[EHCMQLEN_MsgId];          /* Message ID         */
  char           correl[EHCMQLEN_CorrelId];      /* Correlation ID     */
  char           user[EHCMQLEN_UserId];          /* User Identifier    */
  long           wait;                           /* Wait Interval      */
  MSG_OPTION     opt;                            /* GQ Message Options */
 } GQ_REQUEST_PARM;

typedef GQ_REQUEST_PARM *GQ_REQUEST_PARM_P;


/*****************************************************************************/
/* GQ Reply PARMLIST stucture                                                */
/*****************************************************************************/

typedef struct {
  QHANDLE        Qhandle;                        /* Queue Handle       */
  char           Qname[EHCMQLEN_QName];          /* Queue Name         */
  char           msgId[EHCMQLEN_MsgId];          /* Message ID         */
  char           correl[EHCMQLEN_CorrelId];      /* Correlation ID     */
  char           user[EHCMQLEN_UserId];          /* User Identifier    */
  char           replyQ[EHCMQLEN_QName];         /* Reply Queue Name   */
  MSG_TYPE       msgT;                           /* Message Type       */
  MQREASON       MQreason;                       /* MQ Reason Code     */
 } GQ_REPLY_PARM;

typedef GQ_REPLY_PARM *GQ_REPLY_PARM_P;


/*****************************************************************************/
/* PQ & P1 Request PARMLIST stucture                                         */
/*****************************************************************************/

typedef struct {
  QHANDLE        Qhandle;                        /* Queue Handle       */
  char           Qname[EHCMQLEN_QName];          /* Queue Name         */
  char           msgId[EHCMQLEN_MsgId];          /* Message ID         */
  char           correl[EHCMQLEN_CorrelId];      /* Correlation ID     */
  char           user[EHCMQLEN_UserId];          /* User Identifier    */
  char           replyQ[EHCMQLEN_QName];         /* Reply Queue Name   */
  MSG_TYPE       msgT;                           /* Message Type       */
  long           msgExp;                         /* Message Expiry     */
  MSG_OPTION     opt;                            /* PQ Message Options */
 } PQ_REQUEST_PARM;
typedef PQ_REQUEST_PARM *PQ_REQUEST_PARM_P;


/*****************************************************************************/
/* PQ & P1 Reply PARMLIST stucture                                           */
/*****************************************************************************/

typedef struct {
  QHANDLE        Qhandle;                        /* Queue Handle       */
  char           Qname[EHCMQLEN_QName];          /* Queue Name         */
  char           msgId[EHCMQLEN_MsgId];          /* Message ID         */
  char           correl[EHCMQLEN_CorrelId];      /* Correlation ID     */
  char           user[EHCMQLEN_UserId];          /* User Identifier    */
  MQREASON       MQreason;                       /* MQ Reason Code     */
 } PQ_REPLY_PARM;

typedef PQ_REPLY_PARM *PQ_REPLY_PARM_P;

#pragma pack ()


#define GQ_REQUEST_PARM_LEN sizeof(GQ_REQUEST_PARM)
#define GQ_REPLY_PARM_LEN   sizeof(GQ_REPLY_PARM) 
#define PQ_REQUEST_PARM_LEN sizeof(PQ_REQUEST_PARM)
#define PQ_REPLY_PARM_LEN   sizeof(PQ_REPLY_PARM)


/*****************************************************************************/
/* Values that may be useful to define PARMLIST fields                       */
/*****************************************************************************/
/*                     1 2 3 4 5 6 7 8 9   1 2 3 4 5 6 7 8 9   1 2 3 4  */ 
/* The NULL User Identifyer */
#define EHCMQUI_NONE "\0\0\0\0\0\0\0\0\0\0\0\0"

/* The NULL Queue Name  */ 
#define EHCMQQN_NONE "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"

/* The NULL Message Identifier */
#define EHCMQMI_NONE "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"

 /* The NULL Correlation Identifier */
#define EHCMQCI_NONE "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"



#endif   /* if !defined(EHCMQ_INCLUDED)    End of file */

